@@ -98,7 +98,7 @@ typedef gint64 goffset;
 #define G_GOFFSET_FORMAT        G_GINT64_FORMAT
 #define G_GOFFSET_CONSTANT(val) G_GINT64_CONSTANT(val)
 
-#define G_POLLFD_FORMAT "%#x"
+#define G_POLLFD_FORMAT "%#llx"
 
 #define GPOINTER_TO_INT(p)	((gint)  (gint64) (p))
 #define GPOINTER_TO_UINT(p)	((guint) (guint64) (p))
@@ -114,8 +114,8 @@ typedef unsigned long long guintptr;
 #define G_GUINTPTR_FORMAT       "llu"
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 82
-#define GLIB_MICRO_VERSION 5
+#define GLIB_MINOR_VERSION 84
+#define GLIB_MICRO_VERSION 0
 
 #define G_OS_WIN32
 #define G_PLATFORM_WIN32
